==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/internal/pkg/apis/duck/v1/AddressableBuilder.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class AddressableBuilder extends AddressableFluentImpl<AddressableBuilder> implements VisitableBuilder<Addressable,AddressableBuilder> {

    AddressableFluent<?> fluent;
    Boolean validationEnabled;

    public AddressableBuilder() {
        this(true);
    }

    public AddressableBuilder(Boolean validationEnabled) {
        this(new Addressable(), validationEnabled);
    }

    public AddressableBuilder(AddressableFluent<?> fluent) {
        this(fluent, true);
    }

    public AddressableBuilder(AddressableFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Addressable(), validationEnabled);
    }

    public AddressableBuilder(AddressableFluent<?> fluent,Addressable instance) {
        this(fluent, instance, true);
    }

    public AddressableBuilder(AddressableFluent<?> fluent,Addressable instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public AddressableBuilder(Addressable instance) {
        this(instance,true);
    }

    public AddressableBuilder(Addressable instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.internal.pkg.apis.duck.v1.EditableAddressable build() {
        EditableAddressable buildable = new EditableAddressable(fluent.getUrl());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        AddressableBuilder that = (AddressableBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/internal/pkg/apis/duck/v1/AddressableBuilder.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class AddressableBuilder extends AddressableFluentImpl<AddressableBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Addressable,AddressableBuilder> {

    AddressableFluent<?> fluent;
    Boolean validationEnabled;

    public AddressableBuilder() {
        this(true);
    }

    public AddressableBuilder(Boolean validationEnabled) {
        this(new Addressable(), validationEnabled);
    }

    public AddressableBuilder(AddressableFluent<?> fluent) {
        this(fluent, true);
    }

    public AddressableBuilder(AddressableFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Addressable(), validationEnabled);
    }

    public AddressableBuilder(AddressableFluent<?> fluent,Addressable instance) {
        this(fluent, instance, true);
    }

    public AddressableBuilder(AddressableFluent<?> fluent,Addressable instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public AddressableBuilder(Addressable instance) {
        this(instance,true);
    }

    public AddressableBuilder(Addressable instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.internal.pkg.apis.duck.v1.EditableAddressable build() {
        EditableAddressable buildable = new EditableAddressable(fluent.getUrl());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        AddressableBuilder that = (AddressableBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
